# Onionrblocks

Second generation Onionr blocks use [kasten](https://git.voidnet.tech/kev/kasten) with custom generators which create and validate anti-spam and authentication related proofs.

When integrated into the Onionr project, a service will handle saving/loading
